@@ -4,15 +4,29 @@ Language: JavaScript
 
 function(hljs) {
   return {
+    aliases: ['js'],
     keywords: {
       keyword:
         'in if for while finally var new function do return void else break catch ' +
         'instanceof with throw case default try this switch continue typeof delete ' +
-        'let yield const',
+        'let yield const class',
       literal:
-        'true false null undefined NaN Infinity'
+        'true false null undefined NaN Infinity',
+      built_in:
+        'eval isFinite isNaN parseFloat parseInt decodeURI decodeURIComponent ' +
+        'encodeURI encodeURIComponent escape unescape Object Function Boolean Error ' +
+        'EvalError InternalError RangeError ReferenceError StopIteration SyntaxError ' +
+        'TypeError URIError Number Math Date String RegExp Array Float32Array ' +
+        'Float64Array Int16Array Int32Array Int8Array Uint16Array Uint32Array ' +
+        'Uint8Array Uint8ClampedArray ArrayBuffer DataView JSON Intl arguments require ' +
+        'module console window document'
     },
     contains: [
+      {
+        className: 'pi',
+        begin: /^\s*('|")use strict('|")/,
+        relevance: 10
+      },
       hljs.APOS_STRING_MODE,
       hljs.QUOTE_STRING_MODE,
       hljs.C_LINE_COMMENT_MODE,
@@ -27,6 +41,7 @@ function(hljs) {
           hljs.REGEXP_MODE,
           { // E4X
             begin: /</, end: />;/,
+            relevance: 0,
             subLanguage: 'xml'
           }
         ],
@@ -34,12 +49,9 @@ function(hljs) {
       },
       {
         className: 'function',
-        beginWithKeyword: true, end: /{/,
-        keywords: 'function',
+        beginKeywords: 'function', end: /\{/, excludeEnd: true,
         contains: [
-          {
-            className: 'title', begin: /[A-Za-z$_][0-9A-Za-z$_]*/
-          },
+          hljs.inherit(hljs.TITLE_MODE, {begin: /[A-Za-z$_][0-9A-Za-z$_]*/}),
           {
             className: 'params',
             begin: /\(/, end: /\)/,
@@ -51,6 +63,12 @@ function(hljs) {
           }
         ],
         illegal: /\[|%/
+      },
+      {
+        begin: /\$[(.]/ // relevance booster for a pattern common to JS libs: `$(something)` and `$.something`
+      },
+      {
+        begin: '\\.' + hljs.IDENT_RE, relevance: 0 // hack: prevents detection of keywords after dots
       }
     ]
   };
